@@ -1,3 +1,4 @@
+# coding: utf-8
 """
 Augments Python's suite of IO functions with useful transparent support for
 compressed files.
@@ -5,13 +6,6 @@ compressed files.
 
 from __future__ import absolute_import
 
-__author__ = 'Shyue Ping Ong'
-__copyright__ = "Copyright 2014, The Materials Virtual Lab"
-__version__ = '0.1'
-__maintainer__ = 'Shyue Ping Ong'
-__email__ = 'ongsp@ucsd.edu'
-__date__ = '1/24/14'
-
 import os
 import bz2
 import gzip
@@ -19,11 +13,25 @@ import sys
 import time
 import errno
 import mmap
+import subprocess
 
 from io import open
 from monty.tempfile import ScratchDir as ScrDir
 from monty.dev import deprecated
 
+try:
+    from pathlib import Path
+except ImportError:
+    Path = None
+
+__author__ = 'Shyue Ping Ong'
+__copyright__ = "Copyright 2014, The Materials Virtual Lab"
+__version__ = '0.1'
+__maintainer__ = 'Shyue Ping Ong'
+__email__ = 'ongsp@ucsd.edu'
+__date__ = '1/24/14'
+
+
 PY_VERSION = sys.version_info
 
 
@@ -34,7 +42,7 @@ def zopen(filename, *args, **kwargs):
     files.
 
     Args:
-        filename (str): filename
+        filename (str/Path): filename or pathlib.Path.
         \*args: Standard args for python open(..). E.g., 'r' for read, 'w' for
             write.
         \*\*kwargs: Standard kwargs for python open(..).
@@ -42,6 +50,9 @@ def zopen(filename, *args, **kwargs):
     Returns:
         File-like object. Supports with context.
     """
+    if Path is not None and isinstance(filename, Path):
+        filename = str(filename)
+
     file_ext = filename.split(".")[-1].upper()
     if file_ext == "BZ2":
         if PY_VERSION[0] >= 3:
@@ -51,8 +62,8 @@ def zopen(filename, *args, **kwargs):
             if len(args) > 0:
                 args[0] = "".join([c for c in args[0] if c != "t"])
             if "mode" in kwargs:
-                kwargs["mode"] = "".join([c for c in kwargs["mode"] if c !=
-                                          "t"])
+                kwargs["mode"] = "".join([c for c in kwargs["mode"]
+                                          if c != "t"])
             return bz2.BZ2File(filename, *args, **kwargs)
     elif file_ext in ("GZ", "Z"):
         return gzip.open(filename, *args, **kwargs)
@@ -118,8 +129,12 @@ def reverse_readline(m_file, blk_size=4096, max_mem=4000000):
         file.readline() method, except the lines are returned from the back
         of the file.
     """
-
-    file_size = os.path.getsize(m_file.name)
+    try:
+        file_size = os.path.getsize(m_file.name)
+    except AttributeError:
+        # Bz2 files do not have name attribute. Just set file_size to above
+        # max_mem for now.
+        file_size = max_mem + 1
 
     # If the file size is within our desired RAM use, just reverse it in memory
     # GZip files must use this method because there is no way to negative seek
@@ -135,7 +150,7 @@ def reverse_readline(m_file, blk_size=4096, max_mem=4000000):
 
         buf = ""
         m_file.seek(0, 2)
-        lastchar = m_file.read(1)
+        lastchar = m_file.read(1).decode("utf-8")
         trailing_newline = (lastchar == "\n")
 
         while 1:
@@ -152,7 +167,7 @@ def reverse_readline(m_file, blk_size=4096, max_mem=4000000):
                 # Need to fill buffer
                 toread = min(blk_size, pos)
                 m_file.seek(pos - toread, 0)
-                buf = m_file.read(toread) + buf
+                buf = m_file.read(toread).decode("utf-8") + buf
                 m_file.seek(pos - toread, 0)
                 if pos == toread:
                     buf = "\n" + buf
@@ -264,12 +279,10 @@ def get_open_fds():
 
     .. warning: will only work on UNIX-like OS-es.
     """
-    import subprocess
-    import os
-
     pid = os.getpid()
     procs = subprocess.check_output(["lsof", '-w', '-Ff', "-p", str(pid)])
+    procs = procs.decode("utf-8")
 
-    nprocs = len(filter(lambda s: s and s[0] == 'f' and s[1:].isdigit(), procs.split('\n')))
+    return len([s for s in procs.split('\n')
+                if s and s[0] == 'f' and s[1:].isdigit()])
 
-    return nprocs
