@@ -4,6 +4,37 @@ and yaml.
 """
 from __future__ import absolute_import, unicode_literals
 
+import json
+from monty.io import zopen
+from monty.json import MontyEncoder, MontyDecoder
+from monty.msgpack import default, object_hook
+
+try:
+    import ruamel.yaml as yaml
+    try:  # Default to using CLoader and CDumper for speed.
+        from ruamel.yaml import CLoader as Loader
+        from ruamel.yaml import CDumper as Dumper
+    except ImportError:
+        from ruamel.yaml import Loader
+        from ruamel.yaml import Dumper
+except ImportError:
+    try:
+        import yaml
+        try:  # Default to using CLoader and CDumper for speed.
+            from yaml import CLoader as Loader
+            from yaml import CDumper as Dumper
+        except ImportError:
+            from yaml import Loader
+            from yaml import Dumper
+    except ImportError:
+        yaml = None
+
+
+try:
+    import msgpack
+except ImportError:
+    msgpack = None
+
 __author__ = 'Shyue Ping Ong'
 __copyright__ = 'Copyright 2013, The Materials Project'
 __version__ = '0.1'
@@ -12,39 +43,15 @@ __email__ = 'ongsp@ucsd.edu'
 __date__ = '7/29/14'
 
 
-import json
-from monty.io import zopen
-from monty.json import MontyEncoder, MontyDecoder
-from monty.msgpack import default, object_hook
-
-try:
-    import yaml
-    # Use CLoader for faster performance where possible.
-    try:
-        from yaml import CLoader as Loader, CDumper as Dumper
-    except ImportError:
-        from yaml import Loader, Dumper
-except ImportError:
-    yaml = None
-    Loader = None
-
-try:
-    import msgpack
-except ImportError:
-    msgpack = None
-
-
 def loadfn(fn, *args, **kwargs):
     """
     Loads json/yaml/msgpack directly from a filename instead of a
-    File-like object. For YAML, PyYAML must be installed. The file type is
+    File-like object. For YAML, ruamel.yaml must be installed. The file type is
     automatically detected. YAML is assumed if the filename contains "yaml"
-    (lower or upper case). Otherwise, json is always assumed. Furthermore, if
-    pyyaml is compiled with the LibYAML library, the CLoader is automatically
-    chosen for ~10x faster parsing.
+    (lower or upper case). Otherwise, json is always assumed.
 
     Args:
-        fn (str): filename
+        fn (str/Path): filename or pathlib.Path.
         \*args: Any of the args supported by json/yaml.load.
         \*\*kwargs: Any of the kwargs supported by json/yaml.load.
 
@@ -65,7 +72,7 @@ def loadfn(fn, *args, **kwargs):
             if "yaml" in fn.lower():
                 if yaml is None:
                     raise RuntimeError("Loading of YAML files is not "
-                                       "possible as PyYAML is not installed.")
+                                       "possible as ruamel.yaml is not installed.")
                 if "Loader" not in kwargs:
                     kwargs["Loader"] = Loader
                 return yaml.load(fp, *args, **kwargs)
@@ -78,15 +85,13 @@ def loadfn(fn, *args, **kwargs):
 def dumpfn(obj, fn, *args, **kwargs):
     """
     Dump to a json/yaml directly by filename instead of a File-like object.
-    For YAML, PyYAML must be installed. The file type is automatically
+    For YAML, ruamel.yaml must be installed. The file type is automatically
     detected. YAML is assumed if the filename contains "yaml" (lower or upper
-    case). Otherwise, json is always assumed. Furthermore, if pyyaml is
-    compiled with the LibYAML library, the CDumper is automatically chosen
-    for ~10x faster parsing.
+    case). Otherwise, json is always assumed.
 
     Args:
         obj (object): Object to dump.
-        fn (str): filename.
+        fn (str/Path): filename or pathlib.Path.
         \*args: Any of the args supported by json/yaml.dump.
         \*\*kwargs: Any of the kwargs supported by json/yaml.dump.
 
@@ -107,7 +112,7 @@ def dumpfn(obj, fn, *args, **kwargs):
             if "yaml" in fn.lower():
                 if yaml is None:
                     raise RuntimeError("Loading of YAML files is not "
-                                       "possible as PyYAML is not installed.")
+                                       "possible as ruamel.yaml is not installed.")
                 if "Dumper" not in kwargs:
                     kwargs["Dumper"] = Dumper
                 yaml.dump(obj, fp, *args, **kwargs)
